# <img src='https://raw.githack.com/FortAwesome/Font-Awesome/master/svgs/solid/signal.svg' card_color='#40DBB0' width='50' height='50' style='vertical-align:bottom'/> Speedtest
Ask OVOS to run a simple speedtest.

## About 
Run a speedtest with OVOS
This skill uses the speedtest-cli (https://github.com/sivel/speedtest-cli) which runs an internet bandwidth test using speedtest.net.

Be aware that this speedtest relies on the capability of the network-adapter of your Mycroft device.

Examples for Raspberry Pi: 
- Raspberry Pi 3 B  onboard WiFi: max. ~40 Mbit/s, onboard LAN: max. ~100 Mbit/s 
- Raspberry Pi 3 B+ onboard WiFi: max. ~100 Mbit/s, onboard LAN: max. ~225 Mbit/s

If a Raspberry Pi 3 B - connected to WiFi - runs Mycroft you won't get more than 40 Mbit/s from the speedtest despite your internet connection may have more bandwith.

## Examples 
* "Hey mycroft, run a speedtest"

## Credits 
Lukas Gangel (@luke5sky)


## Category
Daily
Information
IoT
**Productivity**

## Tags
#ínternet
#speed
#bandwith
